==> vite-plugin-svg-0.3.0.tgz: package/README.md <==
<h1 align="center">vite-plugin-svg</h1>
<p align="center">Extend Vite with ability to use SVG files as Vue components.</p>

### Features:
- [SVGO](https://github.com/svg/svgo) optimization
- Hot Module Replacement support
- Default SVG import behavior support

### Current state:
POC (please read release notes before updating)

Vite is currently in an experimental state which means this plugin will change accordingly until the plugin API is established and frozen.

#### Currently supported Vite version:

<p><code>0.20.4</code></p>

### Install

```bash
yarn add --dev vite-plugin-svg @vue/compiler-dom

npm i -D vite-plugin-svg @vue/compiler-dom
```

### Usage

To use SVG file as a Vue component you need to append `?component` query string to the path of your file.
This gives you more control over how a particular SVG file should be loaded and processed:

```js
// Get URL to SVG file
import myIconUrl from './svgs/my-icon.svg';

const img = document.createElement('img');
img.src = myIconUrl;
```
```css
.my-icon {
  /* Get URL to SVG file */
  background-image: url("./svgs/my-icon.svg");
}
```
```vue
<template>
  <div>
    <MyIcon />
  </div>
</template>
<script>
import MyIcon from './svgs/my-icon.svg?component'; // Note the `?component` part

export default {
  components: {
    MyIcon,
  },
};
</script>
```

### Setup

#### `vite.config.js`

```js
const svgPlugin = require('vite-plugin-svg');

module.exports = {
  plugins: [
    svgPlugin(),
  ],
};
```

### TODO:
- Convert plugin to TS
- Support disabling SVGO
- Basic test coverage

==> vite-plugin-svg-0.4.0.tgz: package/README.md <==
<h1 align="center">vite-plugin-svg</h1>
<p align="center">Extend Vite with ability to use SVG files as Vue components.</p>

### Features:
- [SVGO](https://github.com/svg/svgo) optimization
- Hot Module Replacement support
- Default SVG import behavior support

### Current state:
POC (please read release notes before updating)

Vite is currently in an experimental state which means this plugin will change accordingly until the plugin API is established and frozen.

#### Currently supported Vite version:

<p><code>0.20.8</code></p>

### Install

```bash
yarn add --dev vite-plugin-svg

npm i -D vite-plugin-svg
```

### Usage

Starting from `v0.4.0` to use SVG file as a component, just import `VueComponent` from the path of the file.
This gives you more control over how a particular SVG file should be loaded and processed:

```js
// Get URL to SVG file
import myIconUrl from './svgs/my-icon.svg';

const img = document.createElement('img');
img.src = myIconUrl;
```
```css
.my-icon {
  /* Get URL to SVG file */
  background-image: url("./svgs/my-icon.svg");
}
```
```vue
<template>
  <div>
    <MyIcon />
  </div>
</template>
<script>
import { VueComponent as MyIcon } from './svgs/my-icon.svg';

export default {
  components: {
    MyIcon,
  },
};
</script>
```

### Setup

#### `vite.config.js`

```js
const svgPlugin = require('vite-plugin-svg');

module.exports = {
  plugins: [
    svgPlugin(),
  ],
};
```

### TODO:
- Convert plugin to TS
- Support disabling SVGO
- Basic test coverage
